
# Copyright 2022, Frank Sauerburger

"""Movie title suggestion api"""

import json
from flask import Flask, request
import qgram

app = Flask(__name__)

with open("examples/titles.json", encoding="utf-8") as fileobj:
    titles = json.load(fileobj)

movie_ids = {}
movie_titles = {}
index = qgram.QGramIndex()
for tid, (title, year) in titles.items():
    tid = int(tid)
    movie_titles[tid] = (title, year)
    movie_ids[title] = tid
    index.add_term(title)


@app.route("/titles")
def suggest():
    """Serve movie title suggestions"""
    query = request.args.get("q")

    try:
        length = int(request.args.get("l", 12))
        length = min(length, 100)
    except ValueError:
        length = 12

    results = []

    if query:
        results = index.search(query)

    results = results[:length]

    results = [
        (score, title, movie_ids[title])
        for score, title in results
    ]

    return {
        "suggestions": results
    }


@app.route("/titles/<mids>")
def byid(mids):
    """Load movie data by id"""
    results = []

    for mid in mids.split(","):
        try:
            mid = int(mid)
            if mid not in movie_titles:
                raise ValueError()
        except ValueError:
            results.append({})
            continue

        res_title, res_year = movie_titles[mid]
        data = {
            "id": mid,
            "title": res_title,
            "year": res_year
        }
        results.append(data)

    return {"movies": results}


@app.route("/titles/healthz")
def healthz():
    """Show healthz status"""
    results = index.search("lord")
    return {"ok": bool(results)}
